<html>
    <head>
        <title>Django Sampler</title>
        <h1>Django Sampler</h1>
        <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}djangosampler/sampler.css" />
    </head>
    <body>
        <div class="menu">
            {% block menu %}{% endblock %}
        </div>
        {% block body %}{% endblock %}
        <div id="footer">Django Sampler written by <a href="http://www.colinhowe.co.uk">Colin Howe</a>. Source on <a href="http://github.com/colinhowe/djangosampler">Github.</a></div>
    </body>
</html>
